import { useContext } from "react";
import { TuitioContext, TuitioDispatchContext } from "../contexts";
import { TuitioClient, invalidate } from "@flare/tuitio-client";
import type { TuitioAuthenticationResult } from "@flare/tuitio-client";

export type TuitioClientHookOptions = {
  onLoginSuccess: (result: TuitioAuthenticationResult, userName: string) => void;
  onLoginFailed: (result: TuitioAuthenticationResult, userName: string) => void;
  onLoginError: (error: any) => void;
};

const useTuitioClient = (options: TuitioClientHookOptions) => {
  const state = useContext(TuitioContext);
  const dispatchActions = useContext(TuitioDispatchContext);

  const { onLoginSuccess, onLoginFailed, onLoginError } = options;

  const login = async (userName: string, password: string) => {
    try {
      const client = new TuitioClient(state.configuration.tuitioUrl);
      const response = await client.authenticate(userName, password);
      if (response.token) {
        dispatchActions.onLoginSuccess(response.token, userName);
        onLoginSuccess && onLoginSuccess(response, userName);
      } else {
        onLoginFailed && onLoginFailed(response, userName);
      }
      return response;
    } catch (error) {
      onLoginError && onLoginError(error);
      throw error;
    }
  };

  const logout = (): void => {
    invalidate();
    dispatchActions.onLogout();
  };

  return { login, logout };
};

export { useTuitioClient };
